@@ -60,13 +60,47 @@ def src_cv(transfer_data):
     max_mip=0,
   )
 
-@pytest.mark.parametrize("lower", (None,255,0))
+def test_threshold_image():
+  import igneous.tasks.image.ccl as ccl
+  sz = 100
+  image = np.arange(0,sz**3).reshape((sz,sz,sz), order="F")
+  image = image.astype(np.uint32)
+
+  res = ccl.threshold_image(image, None, None)  
+  assert np.all(image == res)
+
+  res = ccl.threshold_image(image, sz**3+1, None)  
+  assert np.all(res == 1)
+
+  res = ccl.threshold_image(image, None, 0)  
+  assert np.all(res == 1)
+
+  res = ccl.threshold_image(image, sz**3+1, 0)
+  assert np.all(res == 1)
+
+  res = ccl.threshold_image(image, None, 1)
+  assert np.all(res[0,0,0] == 0)
+  res[0,0,0] = 1
+  assert np.all(res == 1)
+
+  res = ccl.threshold_image(image, sz**3+1, 1)
+  assert np.all(res[0,0,0] == 0)
+  res[0,0,0] = 1
+  assert np.all(res == 1)
+
+@pytest.mark.parametrize("upper", (None,255,0))
 @pytest.mark.parametrize("fill_missing", [True,False])
-def test_ccl_tasks(tq, src_cv, transfer_data, lower, fill_missing):
+@pytest.mark.parametrize("dust_threshold", [0, (64**3) + 1])
+def test_ccl_tasks(
+  tq, src_cv, transfer_data, 
+  upper, fill_missing,
+  dust_threshold
+):
   shape = (128,128,128)
   tasks = tc.create_ccl_face_tasks(
     src_cv.cloudpath, mip=0, shape=shape, 
-    threshold_lte=lower, fill_missing=fill_missing,
+    threshold_lte=upper, fill_missing=fill_missing,
+    dust_threshold=dust_threshold,
   )
   tq.insert_all(tasks)
 
@@ -99,7 +133,8 @@ def test_ccl_tasks(tq, src_cv, transfer_data, lower, fill_missing):
 
   tasks = tc.create_ccl_equivalence_tasks(
     src_cv.cloudpath, mip=0, shape=shape, 
-    threshold_lte=lower, fill_missing=fill_missing,
+    threshold_lte=upper, fill_missing=fill_missing,
+    dust_threshold=dust_threshold,
   )
   tq.insert_all(tasks)
 
@@ -124,8 +159,9 @@ def test_ccl_tasks(tq, src_cv, transfer_data, lower, fill_missing):
   tasks = tc.create_ccl_relabel_tasks(
     src_cv.cloudpath, destpath, 
     mip=0, shape=shape,
-    threshold_lte=lower,
+    threshold_lte=upper,
     fill_missing=fill_missing,
+    dust_threshold=dust_threshold,
   )
   tq.insert_all(tasks)
 
@@ -133,15 +169,23 @@ def test_ccl_tasks(tq, src_cv, transfer_data, lower, fill_missing):
   cc_labels = cv_dest[:][:,:,:,0]
 
   uniq = np.unique(cc_labels)
-  if lower is None:
-    assert len(uniq) == 128
-    assert np.all(uniq == np.arange(1,129))
-  elif lower == 255:
-    assert len(uniq) == 1
-    assert uniq[0] == 1
-  elif lower == 0:
-    assert len(uniq) == 1
-    assert uniq[0] == 0
+  if dust_threshold > 0:
+    if upper in (None, 0):
+      assert len(uniq) == 1
+      assert uniq[0] == 0
+    else:
+      assert len(uniq) == 1
+      assert uniq[0] == 1
+  else:
+    if upper is None:
+      assert len(uniq) == 128
+      assert np.all(uniq == np.arange(1,129))
+    elif upper == 255:
+      assert len(uniq) == 1
+      assert uniq[0] == 1
+    elif upper == 0:
+      assert len(uniq) == 1
+      assert uniq[0] == 0
 
   rmsrc()
   rmdest()
